@@ -3,7 +3,7 @@ import tldextract
 class JobUtils:
 
     def __init__(self):
-        self.tld_extractor = tldextract.TLDExtract(cache_file='../input/tld_lists.txt')
+        self.tld_extractor = tldextract.TLDExtract(cache_file='../tld_lists.txt')
 
     def parse(self, record):
         ext = self.tld_extractor(record)
